==> chezmoi-2.10.1.tar.gz: chezmoi-2.10.1/assets/chezmoi.io/docs/links/articles-podcasts-and-videos.md <==
# Articles, podcasts, and videos

!!! tip

    Recommended article: [Fedora Magazine: Take back your dotfiles with Chezmoi](https://fedoramagazine.org/take-back-your-dotfiles-with-chezmoi/)

!!! tip

    Recommended video: [chezmoi: manage your dotfiles across multiple, diverse machines, securely](https://fosdem.org/2021/schedule/event/chezmoi/)

!!! tip

    Recommended podcast: [Managing Dot Files and an Introduction to Chezmoi](https://www.podfeet.com/blog/2021/07/ccatp-693/)

| Date       | Version | Format      | Link                                                                                                                                                                                                                |
| ---------- | ------- | ----------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| 2022-01-12 | 2.9.5   | Text (IT)   | [Come funzionano i miei Mac](https://correntedebole.com/come-funzionano-i-miei-mac/)                                                                                                                                |
| 2021-12-23 | 2.9.3   | Text        | [Use Chezmoi to guarantee idempotency of terminal](https://www.wazaterm.com/blog/advent-calendar-2021/use-chezmoi-to-guarantee-idempotency-of-terminal)                                                             |
| 2021-12-20 | 2.9.3   | Text        | [How chezmoi Implements Cross-Platform CI](https://gopheradvent.com/calendar/2021/how-chezmoi-implements-cross-platform-ci/)                                                                                        |
| 2021-12-08 | 2.9.3   | Video       | [How Go makes chezmoi possible](https://www.youtube.com/watch?v=5XiewS8ZbH8&t=1044s)                                                                                                                                |
| 2021-12-04 | 2.9.2   | Text        | [Advanced features of Chezmoi](https://zerokspot.com/weblog/2021/12/04/advanced-chezmoi/)                                                                                                                           |
| 2021-11-27 | 2.8.0   | Video (TH)  | [Command ไร 2021-11-27 : ย้าย dotfiles ไป chezmoi](https://www.youtube.com/watch?v=8ybNfCfnF2Y)                                                                                                                      |
| 2021-11-26 | 2.8.0   | Text        | [Weekly Journal 47 - chezmoi, neovim](https://scottbanwart.com/blog/2021/11/weekly-journal-47-chezmoi-neovim/)                                                                                                      |
| 2021-11-23 | 2.8.0   | Text        | [chezmoi dotfile management](https://www.jacobbolda.com/chezmoi-dotfile-management)                                                                                                                                 |
| 2021-10-26 | 2.7.3   | Text (RU)   | [Синхронизация системных настроек](https://habr.com/en/post/585578/)                                                                                                                                                |
| 2021-09-18 | 2.1.2   | Audio/text  | [PBS 125 of X — Chezmoi on Multiple Computers](https://pbs.bartificer.net/pbs125)                                                                                                                                   |
| 2021-09-14 | 2.2.0   | Text        | [Managing preference plists under Chezmoi](https://zacwe.st/2021/09/14/managing-preference-plists-under-chezmoi/)                                                                                                   |
| 2021-09-06 | 2.2.0   | Video       | [chezmoi: Organize your dotfiles across multiple computers \| Let's Code](https://www.youtube.com/watch?v=L_Y3s0PS_Cg)                                                                                              |
| 2021-09-06 | 2.2.0   | Text        | [chezmoi dotfile management](https://www.jacobbolda.com/chezmoi-dotfile-management)                                                                                                                                 |
| 2021-09-04 | 2.2.0   | Text        | [Configuration Management](https://cj.rs/blog/my-setup/chezmoi/)                                                                                                                                                    |
| 2021-09-04 | 2.1.2   | Audio/text  | [PBS 124 of X — Chezmoi Templates](https://pbs.bartificer.net/pbs124)                                                                                                                                               |
| 2021-08-22 | 2.1.2   | Audio/text  | [PBS 123 of X — Backing up and Syncing Dot Files with Chezmoi](https://pbs.bartificer.net/pbs123)                                                                                                                   |
| 2021-08-08 | 2.1.2   | Audio/text  | [PBS 122 of X — Managing Dot Files with Chezmoi](https://pbs.bartificer.net/pbs122)                                                                                                                                 |
| 2021-08-04 | 2.1.2   | Text (PT)   | [Como instalar o Chezmoi, um gerenciador de dotfiles, no Ubuntu, Linux Mint, Fedora, Debian](https://sempreupdate.com.br/como-instalar-o-chezmoi-um-gerenciador-de-dotfiles-no-ubuntu-linux-mint-fedora-debian/)    |
| 2021-07-23 | 2.1.2   | Audio/text  | [PBS 121 of X — Managing Dot Files and an Introduction to Chezmoi](https://www.podfeet.com/blog/2021/07/ccatp-693/)                                                                                                 |
| 2021-07-15 | 2.1.2   | Text (CN)   | [使用Chezmoi管理配置文件](https://marvinsblog.net/post/2021-07-15-chezmoi-intro/)                                                                                                                                   |
| 2021-05-14 | 2.0.12  | Text        | [A brief history of my dotfile management](https://jonathanbartlett.co.uk/2021/05/14/a-brief-history-of-my-dotfiles.html)                                                                                           |
| 2021-05-12 | 2.0.12  | Text        | [My Dotfiles Story: A Journey to Chezmoi](https://www.mikekasberg.com/blog/2021/05/12/my-dotfiles-story.html)                                                                                                       |
| 2021-05-10 | 2.0.11  | Text        | [Development Environment (2021)](https://ideas.offby1.net/posts/development-environment-2021.html)                                                                                                                  |
| 2021-04-20 | 2.0.9   | Text        | [ChezMoi](https://johnmathews.eu/chezmoi.html)                                                                                                                                                                      |
| 2021-04-08 | 2.0.9   | Text (FR)   | [Bienvenue chez moi](https://blogduyax.madyanne.fr/2021/bienvenue-chez-moi/)                                                                                                                                        |
| 2021-04-01 | 2.0.7   | Text        | [ChezMoi](https://johnmathews.is/chezmoi.html)                                                                                                                                                                      |
| 2021-02-17 | 1.8.11  | Text (JP)   | [chezmoi で dotfiles を手軽に柔軟にセキュアに管理する](https://zenn.dev/ryo_kawamata/articles/introduce-chezmoi)                                                                                                    |
| 2021-02-07 | 1.8.10  | Text (JP)   | [chezmoi始めた](https://joe-noh.hatenablog.com/entry/2021/02/07/215733)                                                                                                                                             |
| 2021-02-06 | 1.8.10  | Video       | [chezmoi: manage your dotfiles across multiple, diverse machines, securely](https://fosdem.org/2021/schedule/event/chezmoi/)                                                                                        |
| 2021-01-29 | 1.8.10  | Text (CN)   | [[归档] 用 Chezmoi 管理配置文件](https://axionl.me/p/%E5%BD%92%E6%A1%A3-%E7%94%A8-chezmoi-%E7%AE%A1%E7%90%86%E9%85%8D%E7%BD%AE%E6%96%87%E4%BB%B6/)                                                                  |
| 2021-01-12 | 1.8.10  | Text        | [Automating the Setup of a New Mac With All Your Apps, Preferences, and Development Tools](https://www.moncefbelyamani.com/automating-the-setup-of-a-new-mac-with-all-your-apps-preferences-and-development-tools/) |
| 2020-11-06 | 1.8.8   | Text        | [Chezmoi – Securely Manage dotfiles across multiple machines](https://computingforgeeks.com/chezmoi-manage-dotfiles-across-multiple-machines/)                                                                      |
| 2020-11-05 | 1.8.8   | Text        | [Using chezmoi to manage dotfiles](https://pashinskikh.de/posts/chezmoi/)                                                                                                                                           |
| 2020-10-05 | 1.8.6   | Text        | [Dotfiles with Chezmoi](https://blog.lazkani.io/posts/backup/dotfiles-with-chezmoi/)                                                                                                                                |
| 2020-10-03 | 1.8.6   | Text        | [Chezmoi Merging](https://benoit.srht.site/2020-10-03-chezmoi-merging/)                                                                                                                                             |
| 2020-08-13 | 1.8.3   | Text        | [Using BitWarden and Chezmoi to manage SSH keys](https://www.jx0.uk/chezmoi/bitwarden/unix/ssh/2020/08/13/bitwarden-chezmoi-ssh-key.html)                                                                           |
| 2020-08-09 | 1.8.3   | Text        | [Automating and testing dotfiles](https://seds.nl/posts/automating-and-testing-dotfiles/)                                                                                                                           |
| 2020-08-03 | 1.8.3   | Text        | [Automating a Linux in Windows Dev Setup](https://matt.aimonetti.net/posts/2020-08-automating-a-linux-in-windows-dev-setup/)                                                                                        |
| 2020-07-06 | 1.8.3   | Video       | [Conf42: chezmoi: Manage your dotfiles across multiple machines, securely](https://www.youtube.com/watch?v=JrCMCdvoMAw)                                                                                             |
| 2020-07-03 | 1.8.3   | Text        | [Feeling at home in a LXD container](https://ubuntu.com/blog/feeling-at-home-in-a-lxd-container)                                                                                                                    |
| 2020-06-15 | 1.8.2   | Text        | [Dotfiles management using chezmoi - How I Use Linux Desktop at Work Part5](https://blog.benoitj.ca/2020-06-15-how-i-use-linux-desktop-at-work-part5-dotfiles/)                                                     |
| 2020-04-27 | 1.8.0   | Text        | [Managing my dotfiles with chezmoi](http://blog.emilieschario.com/post/managing-my-dotfiles-with-chezmoi/)                                                                                                          |
| 2020-04-20 | 1.8.0   | Text (FR)   | [Gestion des dotfiles et des secrets avec chezmoi](https://blog.arkey.fr/2020/04/01/manage_dotfiles_with_chezmoi.fr/)                                                                                               |
| 2020-04-19 | 1.7.19  | Text (FR)   | [Git & dotfiles : versionner ses fichiers de configuration](https://www.armandphilippot.com/dotfiles-git-fichiers-configuration/)                                                                                   |
| 2020-04-16 | 1.7.19  | Text (FR)   | [Chezmoi, visite guidée](https://blog.wescale.fr/2020/04/16/chezmoi-visite-guidee/)                                                                                                                                 |
| 2020-04-17 | 1.7.17  | Text (CN)   | [用 Chezmoi 取回你的点文件 | Linux 中国](https://blog.csdn.net/F8qG7f9YD02Pe/article/details/105548429)                                                                                                             |
| 2020-04-03 | 1.7.17  | Text        | [Fedora Magazine: Take back your dotfiles with Chezmoi](https://fedoramagazine.org/take-back-your-dotfiles-with-chezmoi/)                                                                                           |
| 2020-04-01 | 1.7.17  | Text        | [Managing dotfiles and secret with chezmoi](https://blog.arkey.fr/2020/04/01/manage_dotfiles_with_chezmoi/)                                                                                                         |
| 2020-03-12 | 1.7.16  | Video       | [Managing Dotfiles with ChezMoi](https://www.youtube.com/watch?v=HXx6ugA98Qo)                                                                                                                                       |
| 2019-11-20 | 1.7.2   | Audio/video | [FLOSS weekly episode 556: chezmoi](https://twit.tv/shows/floss-weekly/episodes/556)                                                                                                                                |
| 2019-01-10 | 0.0.11  | Text        | [Linux Fu: The kitchen sync](https://hackaday.com/2019/01/10/linux-fu-the-kitchen-sync/)                                                                                                                            |

To add your article to this page please either [open an
issue](https://github.com/twpayne/chezmoi/issues/new/choose) or submit a pull
request that modifies this file (`assets/chezmoi.io/docs/links/media.md`).

==> chezmoi-2.11.0.tar.gz: chezmoi-2.11.0/assets/chezmoi.io/docs/links/articles-podcasts-and-videos.md <==
# Articles, podcasts, and videos

!!! tip

    Recommended article: [Fedora Magazine: Take back your dotfiles with Chezmoi](https://fedoramagazine.org/take-back-your-dotfiles-with-chezmoi/)

!!! tip

    Recommended video: [chezmoi: manage your dotfiles across multiple, diverse machines, securely](https://fosdem.org/2021/schedule/event/chezmoi/)

!!! tip

    Recommended podcast: [Managing Dot Files and an Introduction to Chezmoi](https://www.podfeet.com/blog/2021/07/ccatp-693/)

| Date       | Version | Format      | Link                                                                                                                                                                                                                |
| ---------- | ------- | ----------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| 2022-02-01 | 2.10.1  | Text (JP)   | [chezmoi で dotfiles を手軽に柔軟にセキュアに管理する](https://zenn.dev/ryo_kawamata/articles/introduce-chezmoi)                                                                                                    |
| 2022-01-26 | 2.10.1  | Text (JP)   | [chezmoi で dotfiles を管理する](https://blog.zoncoen.net/2022/01/26/chezmoi/)                                                                                                                                      |
| 2022-01-12 | 2.9.5   | Text (IT)   | [Come funzionano i miei Mac](https://correntedebole.com/come-funzionano-i-miei-mac/)                                                                                                                                |
| 2021-12-23 | 2.9.3   | Text        | [Use Chezmoi to guarantee idempotency of terminal](https://www.wazaterm.com/blog/advent-calendar-2021/use-chezmoi-to-guarantee-idempotency-of-terminal)                                                             |
| 2021-12-20 | 2.9.3   | Text        | [How chezmoi Implements Cross-Platform CI](https://gopheradvent.com/calendar/2021/how-chezmoi-implements-cross-platform-ci/)                                                                                        |
| 2021-12-08 | 2.9.3   | Video       | [How Go makes chezmoi possible](https://www.youtube.com/watch?v=5XiewS8ZbH8&t=1044s)                                                                                                                                |
| 2021-12-04 | 2.9.2   | Text        | [Advanced features of Chezmoi](https://zerokspot.com/weblog/2021/12/04/advanced-chezmoi/)                                                                                                                           |
| 2021-11-27 | 2.8.0   | Video (TH)  | [Command ไร 2021-11-27 : ย้าย dotfiles ไป chezmoi](https://www.youtube.com/watch?v=8ybNfCfnF2Y)                                                                                                                      |
| 2021-11-26 | 2.8.0   | Text        | [Weekly Journal 47 - chezmoi, neovim](https://scottbanwart.com/blog/2021/11/weekly-journal-47-chezmoi-neovim/)                                                                                                      |
| 2021-11-23 | 2.8.0   | Text        | [chezmoi dotfile management](https://www.jacobbolda.com/chezmoi-dotfile-management)                                                                                                                                 |
| 2021-10-26 | 2.7.3   | Text (RU)   | [Синхронизация системных настроек](https://habr.com/en/post/585578/)                                                                                                                                                |
| 2021-09-18 | 2.1.2   | Audio/text  | [PBS 125 of X — Chezmoi on Multiple Computers](https://pbs.bartificer.net/pbs125)                                                                                                                                   |
| 2021-09-14 | 2.2.0   | Text        | [Managing preference plists under Chezmoi](https://zacwe.st/2021/09/14/managing-preference-plists-under-chezmoi/)                                                                                                   |
| 2021-09-06 | 2.2.0   | Video       | [chezmoi: Organize your dotfiles across multiple computers \| Let's Code](https://www.youtube.com/watch?v=L_Y3s0PS_Cg)                                                                                              |
| 2021-09-06 | 2.2.0   | Text        | [chezmoi dotfile management](https://www.jacobbolda.com/chezmoi-dotfile-management)                                                                                                                                 |
| 2021-09-04 | 2.2.0   | Text        | [Configuration Management](https://cj.rs/blog/my-setup/chezmoi/)                                                                                                                                                    |
| 2021-09-04 | 2.1.2   | Audio/text  | [PBS 124 of X — Chezmoi Templates](https://pbs.bartificer.net/pbs124)                                                                                                                                               |
| 2021-08-22 | 2.1.2   | Audio/text  | [PBS 123 of X — Backing up and Syncing Dot Files with Chezmoi](https://pbs.bartificer.net/pbs123)                                                                                                                   |
| 2021-08-08 | 2.1.2   | Audio/text  | [PBS 122 of X — Managing Dot Files with Chezmoi](https://pbs.bartificer.net/pbs122)                                                                                                                                 |
| 2021-08-04 | 2.1.2   | Text (PT)   | [Como instalar o Chezmoi, um gerenciador de dotfiles, no Ubuntu, Linux Mint, Fedora, Debian](https://sempreupdate.com.br/como-instalar-o-chezmoi-um-gerenciador-de-dotfiles-no-ubuntu-linux-mint-fedora-debian/)    |
| 2021-07-23 | 2.1.2   | Audio/text  | [PBS 121 of X — Managing Dot Files and an Introduction to Chezmoi](https://www.podfeet.com/blog/2021/07/ccatp-693/)                                                                                                 |
| 2021-07-15 | 2.1.2   | Text (CN)   | [使用Chezmoi管理配置文件](https://marvinsblog.net/post/2021-07-15-chezmoi-intro/)                                                                                                                                   |
| 2021-05-14 | 2.0.12  | Text        | [A brief history of my dotfile management](https://jonathanbartlett.co.uk/2021/05/14/a-brief-history-of-my-dotfiles.html)                                                                                           |
| 2021-05-12 | 2.0.12  | Text        | [My Dotfiles Story: A Journey to Chezmoi](https://www.mikekasberg.com/blog/2021/05/12/my-dotfiles-story.html)                                                                                                       |
| 2021-05-10 | 2.0.11  | Text        | [Development Environment (2021)](https://ideas.offby1.net/posts/development-environment-2021.html)                                                                                                                  |
| 2021-04-20 | 2.0.9   | Text        | [ChezMoi](https://johnmathews.eu/chezmoi.html)                                                                                                                                                                      |
| 2021-04-08 | 2.0.9   | Text (FR)   | [Bienvenue chez moi](https://blogduyax.madyanne.fr/2021/bienvenue-chez-moi/)                                                                                                                                        |
| 2021-04-01 | 2.0.7   | Text        | [ChezMoi](https://johnmathews.is/chezmoi.html)                                                                                                                                                                      |
| 2021-02-17 | 1.8.11  | Text (JP)   | [chezmoi で dotfiles を手軽に柔軟にセキュアに管理する](https://zenn.dev/ryo_kawamata/articles/introduce-chezmoi)                                                                                                    |
| 2021-02-07 | 1.8.10  | Text (JP)   | [chezmoi始めた](https://joe-noh.hatenablog.com/entry/2021/02/07/215733)                                                                                                                                             |
| 2021-02-06 | 1.8.10  | Video       | [chezmoi: manage your dotfiles across multiple, diverse machines, securely](https://fosdem.org/2021/schedule/event/chezmoi/)                                                                                        |
| 2021-01-29 | 1.8.10  | Text (CN)   | [[归档] 用 Chezmoi 管理配置文件](https://axionl.me/p/%E5%BD%92%E6%A1%A3-%E7%94%A8-chezmoi-%E7%AE%A1%E7%90%86%E9%85%8D%E7%BD%AE%E6%96%87%E4%BB%B6/)                                                                  |
| 2021-01-12 | 1.8.10  | Text        | [Automating the Setup of a New Mac With All Your Apps, Preferences, and Development Tools](https://www.moncefbelyamani.com/automating-the-setup-of-a-new-mac-with-all-your-apps-preferences-and-development-tools/) |
| 2020-11-06 | 1.8.8   | Text        | [Chezmoi – Securely Manage dotfiles across multiple machines](https://computingforgeeks.com/chezmoi-manage-dotfiles-across-multiple-machines/)                                                                      |
| 2020-11-05 | 1.8.8   | Text        | [Using chezmoi to manage dotfiles](https://pashinskikh.de/posts/chezmoi/)                                                                                                                                           |
| 2020-10-05 | 1.8.6   | Text        | [Dotfiles with Chezmoi](https://blog.lazkani.io/posts/backup/dotfiles-with-chezmoi/)                                                                                                                                |
| 2020-10-03 | 1.8.6   | Text        | [Chezmoi Merging](https://benoit.srht.site/2020-10-03-chezmoi-merging/)                                                                                                                                             |
| 2020-08-13 | 1.8.3   | Text        | [Using BitWarden and Chezmoi to manage SSH keys](https://www.jx0.uk/chezmoi/bitwarden/unix/ssh/2020/08/13/bitwarden-chezmoi-ssh-key.html)                                                                           |
| 2020-08-09 | 1.8.3   | Text        | [Automating and testing dotfiles](https://seds.nl/posts/automating-and-testing-dotfiles/)                                                                                                                           |
| 2020-08-03 | 1.8.3   | Text        | [Automating a Linux in Windows Dev Setup](https://matt.aimonetti.net/posts/2020-08-automating-a-linux-in-windows-dev-setup/)                                                                                        |
| 2020-07-06 | 1.8.3   | Video       | [Conf42: chezmoi: Manage your dotfiles across multiple machines, securely](https://www.youtube.com/watch?v=JrCMCdvoMAw)                                                                                             |
| 2020-07-03 | 1.8.3   | Text        | [Feeling at home in a LXD container](https://ubuntu.com/blog/feeling-at-home-in-a-lxd-container)                                                                                                                    |
| 2020-06-15 | 1.8.2   | Text        | [Dotfiles management using chezmoi - How I Use Linux Desktop at Work Part5](https://blog.benoitj.ca/2020-06-15-how-i-use-linux-desktop-at-work-part5-dotfiles/)                                                     |
| 2020-04-27 | 1.8.0   | Text        | [Managing my dotfiles with chezmoi](http://blog.emilieschario.com/post/managing-my-dotfiles-with-chezmoi/)                                                                                                          |
| 2020-04-20 | 1.8.0   | Text (FR)   | [Gestion des dotfiles et des secrets avec chezmoi](https://blog.arkey.fr/2020/04/01/manage_dotfiles_with_chezmoi.fr/)                                                                                               |
| 2020-04-19 | 1.7.19  | Text (FR)   | [Git & dotfiles : versionner ses fichiers de configuration](https://www.armandphilippot.com/dotfiles-git-fichiers-configuration/)                                                                                   |
| 2020-04-16 | 1.7.19  | Text (FR)   | [Chezmoi, visite guidée](https://blog.wescale.fr/2020/04/16/chezmoi-visite-guidee/)                                                                                                                                 |
| 2020-04-17 | 1.7.17  | Text (CN)   | [用 Chezmoi 取回你的点文件](https://blog.csdn.net/F8qG7f9YD02Pe/article/details/105548429)                                                                                                                          |
| 2020-04-03 | 1.7.17  | Text        | [Fedora Magazine: Take back your dotfiles with Chezmoi](https://fedoramagazine.org/take-back-your-dotfiles-with-chezmoi/)                                                                                           |
| 2020-04-01 | 1.7.17  | Text        | [Managing dotfiles and secret with chezmoi](https://blog.arkey.fr/2020/04/01/manage_dotfiles_with_chezmoi/)                                                                                                         |
| 2020-03-12 | 1.7.16  | Video       | [Managing Dotfiles with ChezMoi](https://www.youtube.com/watch?v=HXx6ugA98Qo)                                                                                                                                       |
| 2019-11-20 | 1.7.2   | Audio/video | [FLOSS weekly episode 556: chezmoi](https://twit.tv/shows/floss-weekly/episodes/556)                                                                                                                                |
| 2019-01-10 | 0.0.11  | Text        | [Linux Fu: The kitchen sync](https://hackaday.com/2019/01/10/linux-fu-the-kitchen-sync/)                                                                                                                            |

To add your article to this page please either [open an
issue](https://github.com/twpayne/chezmoi/issues/new/choose) or submit a pull
request that modifies this file (`assets/chezmoi.io/docs/links/media.md`).
